[Libreoffice-commits] core.git: qadevOOo/tests

2013-05-14 Thread Stephan Bergmann
 qadevOOo/tests/java/ifc/accessibility/_XAccessibleComponent.java |7 ++-
 1 file changed, 6 insertions(+), 1 deletion(-)

New commits:
commit 893404cf5e7774ffd9bd6f276586629f9d9d3ae2
Author: Stephan Bergmann sberg...@redhat.com
Date:   Tue May 14 09:18:28 2013 +0200

Improve test log output

Change-Id: I11afb19726ecf6b585d84517cf2a8244800db81a

diff --git a/qadevOOo/tests/java/ifc/accessibility/_XAccessibleComponent.java 
b/qadevOOo/tests/java/ifc/accessibility/_XAccessibleComponent.java
index 1840a85..fd8833b 100644
--- a/qadevOOo/tests/java/ifc/accessibility/_XAccessibleComponent.java
+++ b/qadevOOo/tests/java/ifc/accessibility/_XAccessibleComponent.java
@@ -482,6 +482,11 @@ public class _XAccessibleComponent extends MultiMethodTest 
{
 
 result = (size.Width == bounds.Width);
 result = (size.Height == bounds.Height);
+if (!result) {
+log.println(
+bounds  + bounds.Width + x + bounds.Height +  vs. size 
++ size.Width + x + size.Height);
+}
 
 tRes.tested(getSize(), result);
 }
@@ -628,4 +633,4 @@ public class _XAccessibleComponent extends MultiMethodTest {
 }
 return Covered;
 }
-}
\ No newline at end of file
+}
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: qadevOOo/tests stoc/util udkapi/com ure/source

2013-04-25 Thread Stephan Bergmann
 qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java |   15 +++--
 stoc/util/bootstrap.component  |5 +---
 udkapi/com/sun/star/reflection/TypeDescriptionProvider.idl |4 +++
 ure/source/uretest/cppmain.cc  |1 
 4 files changed, 15 insertions(+), 10 deletions(-)

New commits:
commit 0af9970da3a23f63752033128976ad9ea420f828
Author: Stephan Bergmann sberg...@redhat.com
Date:   Thu Apr 25 17:43:03 2013 +0200

Mark TypeDescriptionProvider service as don't create by name

...had to adapt one test that had picked this service apparently 
arbitrarily.

Change-Id: Iaa17b7c622b9ac3601beb3ba931f7b1d99f649f1

diff --git a/stoc/util/bootstrap.component b/stoc/util/bootstrap.component
index 59761e0..a1f7859 100644
--- a/stoc/util/bootstrap.component
+++ b/stoc/util/bootstrap.component
@@ -35,9 +35,8 @@
 service name=com.sun.star.lang.ServiceManager/
   /implementation
   implementation name=com.sun.star.comp.stoc.OServiceManagerWrapper/
-  implementation 
name=com.sun.star.comp.stoc.RegistryTypeDescriptionProvider
-service name=com.sun.star.reflection.TypeDescriptionProvider/
-  /implementation
+  implementation
+  name=com.sun.star.comp.stoc.RegistryTypeDescriptionProvider/
   implementation name=com.sun.star.comp.stoc.SimpleRegistry
 service name=com.sun.star.registry.SimpleRegistry/
   /implementation
diff --git a/udkapi/com/sun/star/reflection/TypeDescriptionProvider.idl 
b/udkapi/com/sun/star/reflection/TypeDescriptionProvider.idl
index af84f3c..d01581f 100644
--- a/udkapi/com/sun/star/reflection/TypeDescriptionProvider.idl
+++ b/udkapi/com/sun/star/reflection/TypeDescriptionProvider.idl
@@ -31,6 +31,10 @@
 service implementations read from source like the persistent registry
 database format.br
 
+This old-style service definition mostly serves documentation purposes.  It
+is not intended that an implementation of this service can be obtained at
+the global service manager using this service identifier.
+
 @see com::sun::star::reflection::TypeDescriptionManager
 @see com::sun::star::reflection::XTypeDescription
 */
diff --git a/ure/source/uretest/cppmain.cc b/ure/source/uretest/cppmain.cc
index a302b23..331598e 100644
--- a/ure/source/uretest/cppmain.cc
+++ b/ure/source/uretest/cppmain.cc
@@ -112,7 +112,6 @@ private:
 com.sun.star.reflection.CoreReflection,

<    1   2
diff --git a/qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java 
b/qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java
index d6a4483..ce389b1 100644
--- a/qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java
+++ b/qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java
@@ -52,7 +52,7 @@ public class _XEventAttacherManager extends MultiMethodTest {
  */
 public XEventAttacherManager oObj = null;
 
-int index;
+private final int index = 0;
 
 /**
 * Test calls the method and stores index of new entry. p
@@ -60,7 +60,6 @@ public class _XEventAttacherManager extends MultiMethodTest {
 * and no exceptions were thrown. p
 */
 public void _insertEntry() {
-index = 0;
 try {
 oObj.insertEntry(index);
 tRes.tested(insertEntry(), true);
@@ -260,7 +259,7 @@ public class _XEventAttacherManager extends MultiMethodTest 
{
 Object attachedObject;
 
 /**
 * Test creates instance of codeTypeDescriptionProvider/code,
 * stores it and attaches it to the entry with index stored in the method
 * codeinsertEntry()/code. p
 * Has b OK /b status if the method successfully returns
@@ -268,7 +267,6 @@ public class _XEventAttacherManager extends MultiMethodTest 
{
 * The following method tests are to be completed successfully before :
 * ul
 *  li code insertEntry() /code : to have entry's index for 
attach/li
-* @see com.sun.star.reflection.TypeDescriptionProvider
 */
 public void _attach() {
 requiredMethod(insertEntry());
@@ -276,13 +274,18 @@ public class _XEventAttacherManager extends 
MultiMethodTest {
 try {
 XMultiServiceFactory xMSF = (XMultiServiceFactory)tParam.getMSF();
 attachedObject = xMSF.createInstance
-( com.sun.star.reflection.TypeDescriptionProvider );
+( com.sun.star.uno.NamingService );
 } catch( com.sun.star.uno.Exception e ) {
-log.println(Service not available );
+log.println(com.sun.star.uno.NamingService not available );
 e.printStackTrace(log);
 tRes.tested(attach(), false);
 return;
 }
+if (attachedObject == null) {
+log.println(com.sun.star.uno.NamingService not available );
+tRes.tested(attach(), false);
+return;
+}
 
 try {
 oObj.attach(index, attachedObject, param);
@@ -260,7 +259,7 @@ public class _XEventAttacherManager extends MultiMethodTest 
 
 /**
-* Test creates instance of codeTypeDescriptionProvider/code,
+* Test creates instance of codeNamingService/code (arbitrarily),
 * stores it and attaches it to the entry with index stored in the method
 * codeinsertEntry()/code. p